aboutsummaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorBill Wendling <isanbard@gmail.com>2008-02-26 21:11:01 +0000
committerBill Wendling <isanbard@gmail.com>2008-02-26 21:11:01 +0000
commit74ab84c31ef64538a1b56e1f282e49303412ad17 (patch)
treee81fc4181583f23b090bdceca5eda53bed117880 /include
parent4d535cadf159d30619464f61f1386ffc9a340597 (diff)
downloadexternal_llvm-74ab84c31ef64538a1b56e1f282e49303412ad17.zip
external_llvm-74ab84c31ef64538a1b56e1f282e49303412ad17.tar.gz
external_llvm-74ab84c31ef64538a1b56e1f282e49303412ad17.tar.bz2
Change "Name" to "AsmName" in the target register info. Gee, a refactoring tool
would have been a Godsend here! git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@47625 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include')
-rw-r--r--include/llvm/Target/TargetRegisterInfo.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/llvm/Target/TargetRegisterInfo.h b/include/llvm/Target/TargetRegisterInfo.h
index e0fa519..dbf7747 100644
--- a/include/llvm/Target/TargetRegisterInfo.h
+++ b/include/llvm/Target/TargetRegisterInfo.h
@@ -48,7 +48,7 @@ class Type;
/// register, e.g. RAX, EAX, are super-registers of AX.
///
struct TargetRegisterDesc {
- const char *Name; // Assembly language name for the register
+ const char *AsmName; // Assembly language name for the register
const char *PrintableName;// Printable name for the reg (for debugging)
const unsigned *AliasSet; // Register Alias Set, described above
const unsigned *SubRegs; // Sub-register set, described above
@@ -376,10 +376,10 @@ public:
return get(RegNo).SuperRegs;
}
- /// getName - Return the symbolic target specific name for the specified
- /// physical register.
- const char *getName(unsigned RegNo) const {
- return get(RegNo).Name;
+ /// getAsmName - Return the symbolic target specific name for the
+ /// specified physical register.
+ const char *getAsmName(unsigned RegNo) const {
+ return get(RegNo).AsmName;
}
/// getPrintableName - Return the human-readable symbolic target specific name